@@ -9,24 +9,12 @@ try:
 except Exception as e:
     hasWx = False
     WX_VERSION = 0
-    print "EXCEPTION:", str(e)
 
 if hasWx:
     import wx.xrc
     from wx.lib.buttons import GenBitmapTextButton
-
-    #Imports depending on version:
-    if WX_VERSION == 2:
-        from wx.lib.pubsub import Publisher as pub
-
-    if WX_VERSION == 3:
-        from wx.lib.pubsub import pub
-        pub.subscribe
-
-    if WX_VERSION == 4:
-        from wx.lib.pubsub import pub
-        pub.subscribe
-        import wx.adv
+    from pubsub import pub
+    import wx.adv
 
 
 import pytransit
@@ -60,6 +48,13 @@ def main(*args, **kwargs):
         sys.argv.remove("--debug")
         kwargs.pop("-debug")
 
+    if (not args and 'h' in kwargs):
+        print "For commandline mode, please use one of the known methods (or see documentation to add a new one):"
+        for m in all_methods:
+            print "\t - %s" % m
+        print "Usage: python %s <method>" % sys.argv[0]
+        sys.exit(0)
+
     # Check if running in GUI Mode
     if not (args or kwargs) and hasWx:
 
