@@ -30,25 +30,12 @@ try:
 except Exception as e:
     hasWx = False
     WX_VERSION = 0
-    print "EXCEPTION:", str(e)
 
 if hasWx:
     import wx.xrc
     from wx.lib.buttons import GenBitmapTextButton
-
-    #Imports depending on version:
-    if WX_VERSION == 2:
-        from wx.lib.pubsub import Publisher as pub
-
-    if WX_VERSION == 3:
-        from wx.lib.pubsub import pub
-        pub.subscribe
-
-    if WX_VERSION == 4:
-        from wx.lib.pubsub import pub
-        pub.subscribe
-        import wx.adv
-
+    from pubsub import pub
+    import wx.adv
 
 import math
 import ntpath
@@ -153,19 +140,62 @@ def dirname(filepath):
 
 
 def cleanargs(rawargs):
-    #TODO: Write docstring
+    """Returns a list and a dictionary with positional and keyword arguments.
+
+    -This function assumes flags must start with a "-" and and cannot be a 
+        number (but can include them).
+    
+    -Flags should either be followed by the value they want to be associated 
+        with (i.e. -p 5) or will be assigned a value of True in the dictionary.
+
+    -The dictionary will map flags to the name given minus ONE "-" sign in
+        front. If you use TWO minus signs in the flag name (i.e. --verbose), 
+        the dictionary key will be the name with ONE minus sign in front 
+        (i.e. {"-verbose":True}).
+    
+
+    Arguments:
+        rawargs (list): List of positional/keyword arguments. As obtained from
+                         sys.argv.
+
+    Returns:
+        list: List of positional arguments (i.e. arguments without flags),
+                in order provided.
+        dict: Dictionary mapping flag (key is flag minus the first "-") and
+                their values.
+
+    """
     args = []
     kwargs = {}
     count = 0
     # Loop through list of arguments
     while count < len(rawargs):
-        # If the current argument starts with "-"
+        # If the current argument starts with "-", then it's probably a flag
         if rawargs[count].startswith("-"):
-            if count + 1 < len(rawargs) and (not rawargs[count+1].startswith("-") or len(rawargs[count+1].split(" ")) > 1):
+            # Check if next argument is a number
+            try:
+                temp = float(rawargs[count+1])
+                nextIsNumber = True
+            except:
+                nextIsNumber = False
+
+            stillNotFinished = count + 1 < len(rawargs)
+            if stillNotFinished:
+                nextIsNotArgument = not rawargs[count+1].startswith("-")
+                nextLooksLikeList = len(rawargs[count+1].split(" ")) > 1
+            else:
+                nextIsNotArgument = True
+                nextLooksLikeList = False
+
+
+            # If still things in list, and they look like arguments to a flag, add them to dict 
+            if stillNotFinished and (nextIsNotArgument or nextLooksLikeList or nextIsNumber):
                 kwargs[rawargs[count][1:]] = rawargs[count+1]
                 count += 1
+            # Else it's a flag but without arguments/values so assign it True
             else:
                 kwargs[rawargs[count][1:]] = True
+        # Else, it's probably a positional arguement without flags
         else:
             args.append(rawargs[count])
         count += 1
@@ -288,7 +318,7 @@ def validate_wig_format(wig_list, wxobj=None):
             status = 1
             # Get genome
             wc = u"Known Sequence Extensions (*.fna,*.fasta)|*.fna;*.fasta;|\nAll files (*.*)|*.*"
-            gen_dlg = wx.FileDialog(wxobj, message="Save file as ...", defaultDir=os.getcwd(), defaultFile="", wildcard=wc, style=wx.OPEN)
+            gen_dlg = wx.FileDialog(wxobj, message="Save file as ...", defaultDir=os.getcwd(), defaultFile="", wildcard=wc, style=wx.FD_OPEN)
             if gen_dlg.ShowModal() == wx.ID_OK:
                 genome = gen_dlg.GetPath()
             else:
